@@ -34,10 +34,7 @@ def ac_mode_func(args):
     # Object to store user configuration
     user_cfg = ut.UserConfig()
 
-    if '..' not in args.input_file and os.sep not in args.input_file:
-        user_cfg.file_name = '{}/{}'.format(os.getcwd(), args.input_file)
-    else:
-        user_cfg.file_name = args.input_file
+    user_cfg.file_name = args.input_file
 
     # mass, mw
     user_cfg.mass = args.mass
@@ -78,14 +75,12 @@ def ac_mode_func(args):
             in_susc_units, user_cfg.mw, user_cfg.mass
         )
 
-    # Group measurements with same temperature into experiments
-    all_experiments = ac.Experiment.from_measurements(
-        ac_measurements, temp_thresh=args.temp_thresh
-    )
-
-    # Split experiments into sublists separated based on dc field strength
-    all_experiments_sep = ac.Experiment.split_by_field(
-        all_experiments, field_thresh=args.field_thresh
+    # Group measurements into sublists of experiments
+    # Where first dimension uses dc field strength
+    # and second uses temperature
+    all_experiments_sep = ac.Experiment.from_measurements(
+        ac_measurements, temp_thresh=args.temp_thresh,
+        field_thresh=args.field_thresh
     )
 
     if args.process == "plot":
@@ -108,6 +103,7 @@ def ac_mode_func(args):
             ac.interactive_t_select(experiments)
             for experiments in all_experiments_sep
         ]
+        args.discard_off = True
 
     # Generate a model object for each experiment, separated by dc field
     # strength
@@ -142,16 +138,16 @@ def ac_mode_func(args):
                 prev_fit = model.initial_params
 
     unique_dc_fields = np.unique(
-        [experiment.dc_field for experiment in all_experiments]
+        [experiment[0].dc_field for experiment in all_experiments_sep]
     )
 
     # For each field, save to file all associated fit params and model funcs
     for models, experiments, dc_field in zip(all_models_sep, all_experiments_sep, unique_dc_fields): # noqa
-        base_filename = '{}/ac_model_{}_1sigma_{:.5f}Oe'.format(
-            user_cfg.results_dir,
+        base_filename = 'ac_model_{}_1sigma_{:.5f}Oe'.format(
             models[0].NAME.replace(" ", "_"),
             dc_field
         )
+        base_filename = os.path.join(user_cfg.results_dir, base_filename)
         fit_filename = '{}_params.out'.format(base_filename)
         model_filename = '{}_model.out'.format(base_filename)
 
@@ -226,6 +222,8 @@ def ac_mode_func(args):
             AC_model=models[0].NAME,
             sigma=args.sigma
         )
+        if len(tau) == 1:
+            continue
 
         # Select the model function to be used.
         # Set field to zero so Direct is never activated in AC module.
@@ -769,7 +767,7 @@ def read_args(arg_list=None):
         metavar='<number>',
         type=int,
         default=2,
-        help='''Discard initial data points measured under a saturating DC field.
+        help='''Discard initial data points measured under a saturating DC field. # noqa
         Default: 2.'''
     )
     dc_parser.add_argument(
